@@ -8,8 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor ;
-BEGIN {
-  $Config::Model::Tk::LeafEditor::VERSION = '1.325';
+{
+  $Config::Model::Tk::LeafEditor::VERSION = '1.331';
 }
 
 use strict;
@@ -247,7 +247,6 @@ sub store {
                         -text  => $@->as_string,
                       )
             -> Show ;
-        $cw->reset_value ;
     }
     else {
         # trigger redraw of Tk Tree
