@@ -8,8 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListEditor ;
-BEGIN {
-  $Config::Model::Tk::ListEditor::VERSION = '1.325';
+{
+  $Config::Model::Tk::ListEditor::VERSION = '1.331';
 }
 
 use strict;
@@ -87,14 +87,6 @@ sub Populate {
     $balloon->attach( $tklist,
         -msg => 'select an element and perform ' . 'an action on the right' );
 
-    my $cargo_type = $list->cargo_type;
-    my @insert =
-        $cargo_type eq 'leaf'
-      ? $list->fetch_all_values( check => 'no' )
-      : $list->get_all_indexes;
-    map { $_ = '<undef>' unless defined $_ } @insert;
-    $tklist->insert( end => @insert );
-
     my $right_frame =
       $elt_button_frame->Frame->pack( @fxe1, qw/-side right -anchor n/ );
 
@@ -133,6 +125,8 @@ sub Populate {
     )->pack( -side => 'left', @fxe1 );
     $balloon->attach( $rm_all_b, -msg => 'Remove all elements from the list' );
 
+    my $cargo_type = $list->cargo_type;
+
     if ($cargo_type eq 'leaf') {
         my $sort_b = $mv_rm_frame->Button(
             -image   => $sort_img,
@@ -161,6 +155,7 @@ sub Populate {
             ->pack(@fxe1);
 
 	$value_entry -> pack  (@fxe1) ;
+        $cw->add_warning($list, 'edit')->pack(@fx) ;
     }
     else {
         my $elt_name = $list->element_name;
@@ -177,10 +172,31 @@ sub Populate {
 
 
     $cw->{tklist} = $tklist;
+    $cw -> reset_value ;
+
 
     $cw->Tk::Frame::Populate($args);
 }
 
+#
+# New subroutine "reset_value" extracted - Wed Sep 21 11:33:51 2011.
+#
+sub reset_value {
+    my $cw = shift ;
+    my $list = $cw->{list};
+
+    my $cargo_type = $list->cargo_type;
+    $cw->{tklist}->delete (0, 'end') ;
+    my @insert =
+        $cargo_type eq 'leaf'
+      ? $list->fetch_all_values( check => 'no' )
+      : $list->get_all_indexes;
+    map { $_ = '<undef>' unless defined $_ } @insert;
+    $cw->{tklist}->insert( end => @insert );
+
+    return ($cargo_type, \@insert);
+}
+
 sub add_set_entry {
     my ( $cw, $frame, $balloon, $tklist, $user_value_r ) = @_;
 
@@ -249,15 +265,15 @@ sub push_entry {
     }
     else {
 	# trigger redraw of Tk Tree
-	$cw->reload_tree;
+	$cw->{store_cb}->(1);
+
+        my @new_idx = $list->get_all_indexes ;
+        $logger->debug("new list idx: ". join(',',@new_idx));
+
+        my $insert = length($add) ? $add : $#new_idx ;
+        $tklist->insert('end',$insert);
     }
 
-    my @new_idx = $list->get_all_indexes ;
-    $logger->debug("new list idx: ". join(',',@new_idx));
-
-    my $insert = length($add) ? $add : $#new_idx ;
-    $tklist->insert('end',$insert);
-
     return 1 ;
 }
 
@@ -276,7 +292,7 @@ sub set_entry {
     $tklist->insert($idx, $data) ;
     $tklist->selectionSet($idx ) ;
     $cw->{list}->fetch_with_id($idx)->store($data) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 sub add_set_all_b {
@@ -323,7 +339,7 @@ sub set_all_items {
     $tklist->delete(0,'end') ;
     $tklist->insert(0, @list) ;
     $cw->{list}->load_data(\@list) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 sub sort_content {
@@ -337,7 +353,7 @@ sub sort_content {
     $tklist->delete(0,'end') ;
     $tklist->insert(0, @list) ;
     $list->load_data(\@list) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 
@@ -396,7 +412,7 @@ sub swap {
     }
 
     $tklist->selectionSet($idb ) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 sub remove_selection {
@@ -407,8 +423,8 @@ sub remove_selection {
     foreach ($tklist->curselection()) {
 	$logger->debug( "remove_selection: removing index $_" );
 	$list   -> remove($_) ;
-	$cw->reload_tree ;
     }
+    $cw->{store_cb}->(1) ;
 
     # redraw the list content
     $tklist -> delete(0,'end') ;
@@ -417,11 +433,7 @@ sub remove_selection {
                :                         $list->get_all_indexes ;
     map { $_ = '<undef>' unless defined $_ } @insert ;
     $tklist->insert( end => @insert ) ;
-}
-
-sub reload_tree {
-    my $cw = shift ;
-    $cw->{store_cb}->() ;
+    $cw->update_warning($list) ;
 }
 
 
