@@ -11,7 +11,7 @@
 
 package Config::Model::TkUI ;
 {
-  $Config::Model::TkUI::VERSION = '1.329';
+  $Config::Model::TkUI::VERSION = '1.331';
 }
 
 use strict;
@@ -823,7 +823,7 @@ sub disp_leaf {
 
     $tkt->itemCreate($path,2, -text => $cw->trim_value($value)) ;
 
-    $tkt->itemCreate($path,3, -text => $std_v) ;
+    $tkt->itemCreate($path,3, -text => $cw->trim_value($std_v)) ;
 }
 
 sub disp_node {
